==> open-xchange-documents-backend_7.8.0.orig.tar.bz2: open-xchange-documents-backend-7.8.0/com.openexchange.office.realtime/src/com/openexchange/office/realtime/impl/Sync.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.realtime.impl;

import org.apache.commons.logging.Log;
import org.json.JSONException;
import org.json.JSONObject;

/**
 * Contains data that is needed for synchronization purposes between
 * client and server.
 *
 * {@link Sync}
 *
 * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
 * @since v7.6.2
 */
public class Sync {

    private final int SYNC_UNKNOWN_DOCOSN = -1;
    private final String SYNC_FOLDERID = "folderId";
    private final String SYNC_FILEID = "fileId";
    private final String SYNC_DOCOSN = "document-osn";
    private final String SYNC_FILEVERSION = "fileVersion";
    private final String SYNC_SUPPORTSVERSIONS = "supportsVersions";
    private final String SYNC_FILENAME = "fileName";

    public static final String SYNC_INFO = "syncInfo";

    // members
    private int m_documentOperationStateNumber = SYNC_UNKNOWN_DOCOSN;
    private String m_version;
    private final String m_folderId;
    private final String m_fileId;
    private String m_fileName;
    private boolean m_supportsVersions = true;
    private final Log m_log;

    public Sync(final Log log, final String folderId, final String fileId) {
        m_log = log;
        m_folderId = folderId;
        m_fileId = fileId;
        m_supportsVersions = true;
    }

    public boolean isValidSyncInfo() {
        return (m_documentOperationStateNumber != SYNC_UNKNOWN_DOCOSN);
    }

    public void updateSyncInfo(final String version, int docOSN) {
        m_version = version;
        m_documentOperationStateNumber = docOSN;
    }

    public void updateFileVersion(final String version) {
        m_version = version;
    }

    public void updateDocmentOSN(int docOSN) {
        m_documentOperationStateNumber = docOSN;
    }

    public void setSupportsVersions(boolean supportsVersions) {
        m_supportsVersions = supportsVersions;
    }

    public void setFileName(final String fileName) {
        m_fileName = fileName;
    }

    public JSONObject toJSON() {
        final JSONObject jsonObject = new JSONObject();

        try {
            jsonObject.put(SYNC_FOLDERID, m_folderId);
            jsonObject.put(SYNC_FILEID, m_fileId);
            jsonObject.put(SYNC_FILEVERSION, (m_version == null) ? JSONObject.NULL : m_version);
            jsonObject.put(SYNC_DOCOSN, m_documentOperationStateNumber);
            jsonObject.put(SYNC_SUPPORTSVERSIONS, m_supportsVersions);
            jsonObject.put(SYNC_FILENAME, (m_fileName == null) ? JSONObject.NULL : m_fileName);
        } catch (JSONException e) {
            m_log.error("Exception catched while setting sync data", e);
        }

        return jsonObject;
    }
}

==> open-xchange-documents-backend_7.8.2.orig.tar.bz2: open-xchange-documents-backend-7.8.2/com.openexchange.office.realtime/src/com/openexchange/office/realtime/impl/Sync.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.realtime.impl;

import org.apache.commons.logging.Log;
import org.json.JSONException;
import org.json.JSONObject;

/**
 * Contains data that is needed for synchronization purposes between
 * client and server.
 *
 * {@link Sync}
 *
 * @author <a href="mailto:carsten.driesner@open-xchange.com">Carsten Driesner</a>
 * @since v7.6.2
 */
public class Sync {

    private final int SYNC_UNKNOWN_DOCOSN = -1;
    private final String SYNC_FOLDERID = "folderId";
    private final String SYNC_FILEID = "fileId";
    private final String SYNC_DOCOSN = "document-osn";
    private final String SYNC_FILEVERSION = "fileVersion";
    private final String SYNC_SUPPORTSVERSIONS = "supportsVersions";
    private final String SYNC_FILENAME = "fileName";
    private final String SYNC_RESTOREID = "restore_id";

    public static final String SYNC_INFO = "syncInfo";

    // members
    private int m_documentOperationStateNumber = SYNC_UNKNOWN_DOCOSN;
    private String m_version;
    private final String m_folderId;
    private final String m_fileId;
    private String m_fileName;
    private boolean m_supportsVersions = true;
    private String m_restoreID;
    private final Log m_log;

    public Sync(final Log log, final String folderId, final String fileId) {
        m_log = log;
        m_folderId = folderId;
        m_fileId = fileId;
        m_supportsVersions = true;
    }

    public boolean isValidSyncInfo() {
        return (m_documentOperationStateNumber != SYNC_UNKNOWN_DOCOSN);
    }

    public void updateSyncInfo(final String version, int docOSN) {
        m_version = version;
        m_documentOperationStateNumber = docOSN;
    }

    public void updateFileVersion(final String version) {
        m_version = version;
    }

    public void updateDocmentOSN(int docOSN) {
        m_documentOperationStateNumber = docOSN;
    }

    public void setSupportsVersions(boolean supportsVersions) {
        m_supportsVersions = supportsVersions;
    }

    public void setFileName(final String fileName) {
        m_fileName = fileName;
    }

    public void setRestoreID(final String restoreID) {
        m_restoreID = restoreID;
    }

    public JSONObject toJSON() {
        final JSONObject jsonObject = new JSONObject();

        try {
            jsonObject.put(SYNC_FOLDERID, m_folderId);
            jsonObject.put(SYNC_FILEID, m_fileId);
            jsonObject.put(SYNC_FILEVERSION, (m_version == null) ? JSONObject.NULL : m_version);
            jsonObject.put(SYNC_DOCOSN, m_documentOperationStateNumber);
            jsonObject.put(SYNC_SUPPORTSVERSIONS, m_supportsVersions);
            jsonObject.put(SYNC_FILENAME, (m_fileName == null) ? JSONObject.NULL : m_fileName);
            jsonObject.put(SYNC_RESTOREID, (m_restoreID == null) ? JSONObject.NULL : m_restoreID);
        } catch (JSONException e) {
            m_log.error("Exception caught while setting sync data", e);
        }

        return jsonObject;
    }
}
